@@ -233,6 +233,14 @@ static gnutls_error_entry error_algorithms[] = {
 	       GNUTLS_E_CONSTRAINT_ERROR, 1),
   ERROR_ENTRY ("Failed to acquire random data.", GNUTLS_E_RANDOM_FAILED,
 	       1),
+
+  ERROR_ENTRY("Received a TLS/IA Intermediate Phase Finished message",
+	      GNUTLS_E_WARNING_IA_IPHF_RECEIVED, 0),
+  ERROR_ENTRY("Received a TLS/IA Final Phase Finished message",
+	      GNUTLS_E_WARNING_IA_FPHF_RECEIVED, 0),
+  ERROR_ENTRY("Verifying TLS/IA phase checksum failed",
+	      GNUTLS_E_IA_VERIFY_FAILED, 1),
+
   {NULL, NULL, 0, 0}
 };
 
