@@ -34,6 +34,7 @@
 #include <ext_cert_type.h>
 #include <ext_server_name.h>
 #include <ext_srp.h>
+#include <ext_inner_application.h>
 #include <gnutls_num.h>
 
 /* Key Exchange Section */
@@ -59,6 +60,9 @@ gnutls_extension_entry _gnutls_extensions[MAX_EXT_SIZE] = {
 			  _gnutls_srp_recv_params,
 			  _gnutls_srp_send_params),
 #endif
+  GNUTLS_EXTENSION_ENTRY(GNUTLS_EXTENSION_INNER_APPLICATION,
+			 _gnutls_inner_application_recv_params,
+			 _gnutls_inner_application_send_params),
   {0, 0, 0, 0}
 };
 
@@ -73,7 +77,7 @@ gnutls_extension_entry _gnutls_extensions[MAX_EXT_SIZE] = {
 /* EXTENSION functions */
 
 ext_recv_func
-_gnutls_ext_func_recv (uint16 type)
+_gnutls_ext_func_recv (uint16_t type)
 {
   ext_recv_func ret = NULL;
   GNUTLS_EXTENSION_LOOP (ret = p->gnutls_ext_func_recv);
@@ -82,7 +86,7 @@ _gnutls_ext_func_recv (uint16 type)
 }
 
 ext_send_func
-_gnutls_ext_func_send (uint16 type)
+_gnutls_ext_func_send (uint16_t type)
 {
   ext_send_func ret = NULL;
   GNUTLS_EXTENSION_LOOP (ret = p->gnutls_ext_func_send);
@@ -91,7 +95,7 @@ _gnutls_ext_func_send (uint16 type)
 }
 
 const char *
-_gnutls_extension_get_name (uint16 type)
+_gnutls_extension_get_name (uint16_t type)
 {
   const char *ret = NULL;
 
@@ -105,7 +109,7 @@ _gnutls_extension_get_name (uint16 type)
  * requested ones. Otherwise it's a fatal error.
  */
 static int
-_gnutls_extension_list_check (gnutls_session_t session, uint16 type)
+_gnutls_extension_list_check (gnutls_session_t session, uint16_t type)
 {
   if (session->security_parameters.entity == GNUTLS_CLIENT)
     {
@@ -127,10 +131,10 @@ _gnutls_parse_extensions (gnutls_session_t session, const opaque * data,
 {
   int next, ret;
   int pos = 0;
-  uint16 type;
+  uint16_t type;
   const opaque *sdata;
   ext_recv_func ext_recv;
-  uint16 size;
+  uint16_t size;
 
 #ifdef DEBUG
   int i;
@@ -196,7 +200,7 @@ _gnutls_parse_extensions (gnutls_session_t session, const opaque * data,
  * extensions are the ones we requested.
  */
 static void
-_gnutls_extension_list_add (gnutls_session_t session, uint16 type)
+_gnutls_extension_list_add (gnutls_session_t session, uint16_t type)
 {
 
   if (session->security_parameters.entity == GNUTLS_CLIENT)
@@ -218,12 +222,12 @@ int
 _gnutls_gen_extensions (gnutls_session_t session, opaque * data,
 			size_t data_size)
 {
-  int next, size;
-  uint16 pos = 0;
+  int size;
+  uint16_t pos = 0;
   opaque *sdata;
   int sdata_size;
   ext_send_func ext_send;
-
+  gnutls_extension_entry *p;
 
   if (data_size < 2)
     {
@@ -242,11 +246,9 @@ _gnutls_gen_extensions (gnutls_session_t session, opaque * data,
     }
 
   pos += 2;
-  next = MAX_EXT_TYPES;		/* maximum supported extensions */
-  do
+  for(p = _gnutls_extensions; p->name != NULL; p++)
     {
-      next--;
-      ext_send = _gnutls_ext_func_send (next);
+      ext_send = _gnutls_ext_func_send(p->type);
       if (ext_send == NULL)
 	continue;
       size = ext_send (session, sdata, sdata_size);
@@ -260,7 +262,7 @@ _gnutls_gen_extensions (gnutls_session_t session, opaque * data,
 	    }
 
 	  /* write extension type */
-	  _gnutls_write_uint16 (next, &data[pos]);
+	  _gnutls_write_uint16(p->type, &data[pos]);
 	  pos += 2;
 
 	  /* write size */
@@ -272,10 +274,10 @@ _gnutls_gen_extensions (gnutls_session_t session, opaque * data,
 
 	  /* add this extension to the extension list
 	   */
-	  _gnutls_extension_list_add (session, next);
+	  _gnutls_extension_list_add(session, p->type);
 
 	  _gnutls_debug_log ("EXT[%x]: Sending extension %s\n", session,
-			     _gnutls_extension_get_name (next));
+			     _gnutls_extension_get_name (p->type));
 	}
       else if (size < 0)
 	{
@@ -283,9 +285,7 @@ _gnutls_gen_extensions (gnutls_session_t session, opaque * data,
 	  gnutls_free (sdata);
 	  return size;
 	}
-
     }
-  while (next >= 0);
 
   size = pos;
   pos -= 2;			/* remove the size of the size header! */
