@@ -137,7 +137,8 @@ typedef enum handshake_state_t
 typedef enum extensions_t
 { GNUTLS_EXTENSION_SERVER_NAME = 0,
   GNUTLS_EXTENSION_MAX_RECORD_SIZE = 1, GNUTLS_EXTENSION_SRP = 6,
-  GNUTLS_EXTENSION_CERT_TYPE = 7
+  GNUTLS_EXTENSION_CERT_TYPE = 7,
+  GNUTLS_EXTENSION_INNER_APPLICATION = 37703
 } extensions_t;
 
 typedef enum
@@ -154,7 +155,8 @@ typedef enum resumable_session_t
 typedef enum content_type_t
 {
   GNUTLS_CHANGE_CIPHER_SPEC = 20, GNUTLS_ALERT,
-  GNUTLS_HANDSHAKE, GNUTLS_APPLICATION_DATA
+  GNUTLS_HANDSHAKE, GNUTLS_APPLICATION_DATA,
+  GNUTLS_INNER_APPLICATION = 24
 } content_type_t;
 
 #define GNUTLS_PK_ANY (gnutls_pk_algorithm_t)-1
@@ -209,7 +211,7 @@ struct gnutls_key_st
   gnutls_credentials_type_t auth_info_type;
   int auth_info_size;		/* needed in order to store to db for restoring 
 				 */
-  uint8 crypt_algo;
+  uint8_t crypt_algo;
 
   auth_cred_st *cred;		/* used to specify keys/certificates etc */
 
@@ -235,7 +237,7 @@ typedef struct gnutls_key_st *gnutls_key_st;
 
 typedef struct
 {
-  uint8 suite[2];
+  uint8_t suite[2];
 } cipher_suite_st;
 
 /* This structure holds parameters got from TLS extension
@@ -246,7 +248,7 @@ typedef struct
 typedef struct
 {
   opaque name[MAX_SERVER_NAME_SIZE];
-  uint name_length;
+  unsigned name_length;
   gnutls_server_name_type_t type;
 } server_name_st;
 
@@ -256,8 +258,11 @@ typedef struct
 {
   server_name_st server_names[MAX_SERVER_NAME_EXTENSIONS];
   /* limit server_name extensions */
-  uint server_names_size;
+  unsigned server_names_size;
   opaque srp_username[MAX_SRP_USERNAME + 1];
+  /* 0 = tls/ia not used, 1 = no, 2 = yes */
+  gnutls_ia_mode_t peer_mode;
+  int inner_phase_optional;
 } tls_ext_st;
 
 /* auth_info_t structures now MAY contain malloced 
@@ -303,18 +308,20 @@ typedef struct
   opaque client_random[TLS_RANDOM_SIZE];
   opaque server_random[TLS_RANDOM_SIZE];
   opaque session_id[TLS_MAX_SESSION_ID_SIZE];
-  uint8 session_id_size;
+  uint8_t session_id_size;
   time_t timestamp;
   tls_ext_st extensions;
 
   /* The send size is the one requested by the programmer.
    * The recv size is the one negotiated with the peer.
    */
-  uint16 max_record_send_size;
-  uint16 max_record_recv_size;
+  uint16_t max_record_send_size;
+  uint16_t max_record_recv_size;
   /* holds the negotiated certificate type */
   gnutls_certificate_type_t cert_type;
   gnutls_protocol_t version;	/* moved here */
+  /* For TLS/IA.  XXX: Move to IA credential? */
+  opaque inner_secret[TLS_MASTER_SIZE];
 } security_parameters_st;
 
 /* This structure holds the generated keys
@@ -391,6 +398,7 @@ typedef struct
   mac_hd_t handshake_mac_handle_md5;	/* hash of the handshake messages */
 
   gnutls_buffer handshake_data_buffer;	/* this is a buffer that holds the current handshake message */
+  gnutls_buffer ia_data_buffer;		/* holds inner application data (TLS/IA) */
   resumable_session_t resumable;	/* TRUE or FALSE - if we can resume that session */
   handshake_state_t handshake_state;	/* holds
 					 * a number which indicates where
@@ -475,8 +483,8 @@ typedef struct
    * This is obtained by the Handshake Client Hello 
    * message. (some implementations read the Record version)
    */
-  uint8 adv_version_major;
-  uint8 adv_version_minor;
+  uint8_t adv_version_major;
+  uint8_t adv_version_minor;
 
   /* if this is non zero a certificate request message
    * will be sent to the client. - only if the ciphersuite
@@ -488,7 +496,7 @@ typedef struct
    * use _gnutls_dh_get_prime_bits() and gnutls_dh_set_prime_bits() 
    * to access it.
    */
-  uint16 dh_prime_bits;
+  uint16_t dh_prime_bits;
 
   size_t max_handshake_data_buffer_size;
 
@@ -513,7 +521,7 @@ typedef struct
   /* Holds the record size requested by the
    * user.
    */
-  uint16 proposed_record_size;
+  uint16_t proposed_record_size;
 
   /* holds the selected certificate and key.
    * use _gnutls_selected_certs_deinit() and _gnutls_selected_certs_set()
@@ -527,8 +535,8 @@ typedef struct
   /* holds the extensions we sent to the peer
    * (in case of a client)
    */
-  uint16 extensions_sent[MAX_EXT_TYPES];
-  uint16 extensions_sent_size;
+  uint16_t extensions_sent[MAX_EXT_TYPES];
+  uint16_t extensions_sent_size;
 
   /* is 0 if we are to send the whole PGP key, or non zero
    * if the fingerprint is to be sent.
