@@ -95,6 +95,10 @@ generate_normal_master (gnutls_session_t session, int keep_premaster)
 		     session->security_parameters.master_secret);
     }
 
+  /* TLS/IA inner secret is derived from the master secret. */
+  memcpy (session->security_parameters.inner_secret,
+	  session->security_parameters.master_secret, TLS_MASTER_SIZE);
+
   if (!keep_premaster)
     _gnutls_free_datum (&PREMASTER);
 
@@ -117,7 +121,7 @@ generate_normal_master (gnutls_session_t session, int keep_premaster)
 int
 _gnutls_send_server_kx_message (gnutls_session_t session, int again)
 {
-  uint8 *data = NULL;
+  uint8_t *data = NULL;
   int data_size = 0;
   int ret = 0;
 
@@ -165,7 +169,7 @@ _gnutls_send_server_kx_message (gnutls_session_t session, int again)
 int
 _gnutls_send_server_certificate_request (gnutls_session_t session, int again)
 {
-  uint8 *data = NULL;
+  uint8_t *data = NULL;
   int data_size = 0;
   int ret = 0;
 
@@ -211,7 +215,7 @@ _gnutls_send_server_certificate_request (gnutls_session_t session, int again)
 int
 _gnutls_send_client_kx_message (gnutls_session_t session, int again)
 {
-  uint8 *data;
+  uint8_t *data;
   int data_size;
   int ret = 0;
 
@@ -254,7 +258,7 @@ _gnutls_send_client_kx_message (gnutls_session_t session, int again)
 int
 _gnutls_send_client_certificate_verify (gnutls_session_t session, int again)
 {
-  uint8 *data;
+  uint8_t *data;
   int ret = 0;
   int data_size;
 
@@ -305,7 +309,7 @@ _gnutls_send_client_certificate_verify (gnutls_session_t session, int again)
 int
 _gnutls_recv_server_kx_message (gnutls_session_t session)
 {
-  uint8 *data = NULL;
+  uint8_t *data = NULL;
   int datasize;
   int ret = 0;
 
@@ -350,7 +354,7 @@ _gnutls_recv_server_kx_message (gnutls_session_t session)
 int
 _gnutls_recv_server_certificate_request (gnutls_session_t session)
 {
-  uint8 *data;
+  uint8_t *data;
   int datasize;
   int ret = 0;
 
@@ -383,7 +387,7 @@ _gnutls_recv_server_certificate_request (gnutls_session_t session)
 int
 _gnutls_recv_client_kx_message (gnutls_session_t session)
 {
-  uint8 *data;
+  uint8_t *data;
   int datasize;
   int ret = 0;
 
@@ -418,7 +422,7 @@ _gnutls_recv_client_kx_message (gnutls_session_t session)
 int
 _gnutls_send_client_certificate (gnutls_session_t session, int again)
 {
-  uint8 *data = NULL;
+  uint8_t *data = NULL;
   int data_size = 0;
   int ret = 0;
 
@@ -488,7 +492,7 @@ _gnutls_send_client_certificate (gnutls_session_t session, int again)
 int
 _gnutls_send_server_certificate (gnutls_session_t session, int again)
 {
-  uint8 *data = NULL;
+  uint8_t *data = NULL;
   int data_size = 0;
   int ret = 0;
 
@@ -664,7 +668,7 @@ _gnutls_recv_server_certificate (gnutls_session_t session)
 int
 _gnutls_recv_client_certificate_verify_message (gnutls_session_t session)
 {
-  uint8 *data;
+  uint8_t *data;
   int datasize;
   int ret = 0;
 
