@@ -54,7 +54,7 @@ static int _gnutls_pk_decrypt (int algo, mpi_t * resarr, mpi_t data,
 int
 _gnutls_pkcs1_rsa_encrypt (gnutls_datum_t * ciphertext,
 			   const gnutls_datum_t * plaintext,
-			   mpi_t * params, uint params_len, uint btype)
+			   mpi_t * params, unsigned params_len, unsigned btype)
 {
   unsigned int i, pad;
   int ret;
@@ -207,9 +207,9 @@ _gnutls_pkcs1_rsa_encrypt (gnutls_datum_t * ciphertext,
 int
 _gnutls_pkcs1_rsa_decrypt (gnutls_datum_t * plaintext,
 			   const gnutls_datum_t * ciphertext,
-			   mpi_t * params, uint params_len, uint btype)
+			   mpi_t * params, unsigned params_len, unsigned btype)
 {
-  uint k, i;
+  unsigned k, i;
   int ret;
   mpi_t c, res;
   opaque *edata;
@@ -425,7 +425,7 @@ encode_ber_rs (gnutls_datum_t * sig_value, mpi_t r, mpi_t s)
 int
 _gnutls_dsa_sign (gnutls_datum_t * signature,
 		  const gnutls_datum_t * hash, mpi_t * params,
-		  uint params_len)
+		  unsigned params_len)
 {
   mpi_t rs[2], mdata;
   int ret;
