@@ -309,12 +309,12 @@ _gnutls_send_int (gnutls_session_t session, content_type_t type,
 		  gnutls_handshake_description_t htype, const void *_data,
 		  size_t sizeofdata)
 {
-  uint8 *cipher;
+  uint8_t *cipher;
   int cipher_size;
   int retval, ret;
   int data2send_size;
-  uint8 headers[5];
-  const uint8 *data = _data;
+  uint8_t headers[5];
+  const uint8_t *data = _data;
   int erecord_size = 0;
   opaque *erecord = NULL;
 
@@ -481,6 +481,7 @@ check_recv_type (content_type_t recv_type)
     case GNUTLS_ALERT:
     case GNUTLS_HANDSHAKE:
     case GNUTLS_APPLICATION_DATA:
+    case GNUTLS_INNER_APPLICATION:
       return 0;
     default:
       gnutls_assert ();
@@ -497,7 +498,9 @@ static int
 check_buffers (gnutls_session_t session, content_type_t type,
 	       opaque * data, int sizeofdata)
 {
-  if ((type == GNUTLS_APPLICATION_DATA || type == GNUTLS_HANDSHAKE)
+  if ((type == GNUTLS_APPLICATION_DATA ||
+       type == GNUTLS_HANDSHAKE ||
+       type == GNUTLS_INNER_APPLICATION)
       && _gnutls_record_buffer_get_size (type, session) > 0)
     {
       int ret, ret2;
@@ -530,11 +533,11 @@ check_buffers (gnutls_session_t session, content_type_t type,
  */
 static int
 record_check_headers (gnutls_session_t session,
-		      uint8 headers[RECORD_HEADER_SIZE], content_type_t type,
+		      uint8_t headers[RECORD_HEADER_SIZE], content_type_t type,
 		      gnutls_handshake_description_t htype,
 		      /*output */ content_type_t * recv_type,
-		      opaque version[2], uint16 * length,
-		      uint16 * header_size)
+		      opaque version[2], uint16_t * length,
+		      uint16_t * header_size)
 {
 
   /* Read the first two bytes to determine if this is a 
@@ -634,7 +637,9 @@ record_check_type (gnutls_session_t session,
   int ret;
 
   if ((recv_type == type)
-      && (type == GNUTLS_APPLICATION_DATA || type == GNUTLS_HANDSHAKE))
+      && (type == GNUTLS_APPLICATION_DATA ||
+	  type == GNUTLS_HANDSHAKE ||
+	  type == GNUTLS_INNER_APPLICATION))
     {
       _gnutls_record_buffer_put (type, session, (void *) data, data_size);
     }
@@ -730,6 +735,17 @@ record_check_type (gnutls_session_t session,
 	  /* So we accept it */
 	  return _gnutls_recv_hello_request (session, data, data_size);
 
+	  break;
+	case GNUTLS_INNER_APPLICATION:
+	  /* even if data is unexpected put it into the buffer */
+	  if ((ret = _gnutls_record_buffer_put(recv_type, session,
+					       (void *) data,
+					       data_size)) < 0) {
+	    gnutls_assert();
+	    return ret;
+	  }
+	  gnutls_assert();
+	  return GNUTLS_E_UNEXPECTED_PACKET;
 	  break;
 	default:
 
@@ -803,13 +819,13 @@ _gnutls_recv_int (gnutls_session_t session, content_type_t type,
   gnutls_datum_t tmp;
   int decrypted_length;
   opaque version[2];
-  uint8 *headers;
+  uint8_t *headers;
   content_type_t recv_type;
-  uint16 length;
-  uint8 *ciphertext;
-  uint8 *recv_data;
+  uint16_t length;
+  uint8_t *ciphertext;
+  uint8_t *recv_data;
   int ret, ret2;
-  uint16 header_size;
+  uint16_t header_size;
   int empty_packet = 0;
 
   if (type != GNUTLS_ALERT && (sizeofdata == 0 || data == NULL))
@@ -1008,8 +1024,10 @@ begin:
 
 /* Get Application data from buffer 
  */
-  if ((type == GNUTLS_APPLICATION_DATA || type == GNUTLS_HANDSHAKE)
-      && (recv_type == type))
+  if ((recv_type == type) &&
+      (type == GNUTLS_APPLICATION_DATA ||
+       type == GNUTLS_HANDSHAKE ||
+       type == GNUTLS_INNER_APPLICATION))
     {
 
       ret = _gnutls_record_buffer_get (type, session, data, sizeofdata);
