@@ -537,7 +537,7 @@ gnutls_fingerprint (gnutls_digest_algorithm_t algo,
   GNUTLS_HASH_HANDLE td;
   int hash_len = _gnutls_hash_get_algo_len (HASH2MAC (algo));
 
-  if (hash_len < 0 || (uint) hash_len > *result_size || result == NULL)
+  if (hash_len < 0 || (unsigned) hash_len > *result_size || result == NULL)
     {
       *result_size = hash_len;
       return GNUTLS_E_SHORT_MEMORY_BUFFER;
@@ -649,3 +649,39 @@ gnutls_certificate_set_rsa_export_params (gnutls_certificate_credentials_t
 {
   res->rsa_params = rsa_params;
 }
+
+/**
+  * gnutls_psk_set_params_function - This function will set the DH or RSA parameters callback
+  * @res: is a gnutls_psk_server_credentials_t structure
+  * @func: is the function to be called
+  *
+  * This function will set a callback in order for the server to get the 
+  * diffie hellman or RSA parameters for psk authentication. The callback
+  * should return zero on success.
+  *
+  **/
+void
+gnutls_psk_set_params_function (gnutls_psk_server_credentials_t res,
+					gnutls_params_function * func)
+{
+  res->params_func = func;
+}
+
+
+
+/**
+  * gnutls_anon_set_params_function - This function will set the DH or RSA parameters callback
+  * @res: is a gnutls_anon_server_credentials_t structure
+  * @func: is the function to be called
+  *
+  * This function will set a callback in order for the server to get the 
+  * diffie hellman or RSA parameters for anonymous authentication. The callback
+  * should return zero on success.
+  *
+  **/
+void
+gnutls_anon_set_params_function (gnutls_anon_server_credentials_t res,
+					gnutls_params_function * func)
+{
+  res->params_func = func;
+}
