@@ -13,7 +13,7 @@ typedef struct
   int type;
   int armored;
   size_t size;
-  uint8 *data;
+  uint8_t *data;
 } keybox_blob;
 
 typedef enum
@@ -57,7 +57,7 @@ int gnutls_openpgp_get_key (gnutls_datum_t * key,
 			    key_attr_t by, opaque * pattern);
 
 int gnutls_openpgp_recv_key (const char *host,
-			     short port, uint32 keyid, gnutls_datum_t * key);
+			     short port, uint32_t keyid, gnutls_datum_t * key);
 
 /* internal */
 int _gnutls_openpgp_raw_key_to_gcert (gnutls_cert * cert,
